@@ -545,14 +545,14 @@ class RegExType(object):
     def __repr__(self):
         return "RegEx"
 
-class GPSLocation(StrType):
+class GPSLocationType(StrType):
     """Type for validating a GPS location"""
 
     def __init__(self):
-        super(GPSLocation, self).__init__(allowEmpty=False)
+        super(GPSLocationType, self).__init__(allowEmpty=False)
 
     def __call__(self, inVal):
-        inVal = super(GPSLocation, self).__call__(inVal)
+        inVal = super(GPSLocationType, self).__call__(inVal)
         pieces = [s.strip(" ()[]") for s in _re.split(r",\s*", inVal)]
         if len(pieces) != 2:
             raise InvalidArgumentError("{} is not a valid GPS coordinate".format(inVal))
